@@ -6,15 +6,12 @@ class Database(DataAsset):
     def __init__(self, oddrn: str) -> None:
         self.oddrn = oddrn
 
-    def to_data_entity(self) -> DataEntity:
-        ...
+    def to_data_entity(self) -> DataEntity: ...
 
 
 class Postgres(Database):
-    def to_data_entity(self) -> DataEntity:
-        ...
+    def to_data_entity(self) -> DataEntity: ...
 
 
 class MySQL(Database):
-    def to_data_entity(self) -> DataEntity:
-        ...
+    def to_data_entity(self) -> DataEntity: ...
